<template>
  <div class="video-player" :class="{ ready: ready }" @click="sound.dialog = false">
    <div class="video-player__title" :class="{ playing: video.state.playing === 'playing' }" ref="videoTitle">
      <h2>{{ title }}</h2>
    </div>
    <div class="video-player__video">
      <div v-if="loading" class="video-player__loader">{{ loader }}</div>
      <video
        class="video-player__video__element"
        controls
        preload="metadata"
        ref="videoElement"
        @loadedmetadata="setLength"
        @timeupdate="timeUpdateFunction"
        @canplay="loading = false"
      >
        <source v-for="source in videoSources" :key="source.src" :src="source.src" :type="source.type" />
        Текущий браузер не поддерживает воспроизведение этого видео.
      </video>
      <div class="video-player__video__control left" @click="timeChangeBack"></div>
      <div class="video-player__video__control right" @click="timeChangeFw"></div>
    </div>
    <div :class="{ playing: video.state.playing === 'playing', loading: loading }" class="video-player__controls" ref="videoControls">
      <div class="progressbar">
        <div class="progressbar__time start">{{ formatTime(video.state.timeNow).minutes }}:{{ formatTime(video.state.timeNow).seconds }}</div>
        <div class="progressbar__center">
          <div class="progressbar__progress" :style="{ backgroundSize: video.state.position + '% 100%' }">
            <div class="trumb" :style="{ left: video.state.position + '%' }"></div>
          </div>
          <input
            class="progressbar__seek"
            min="0"
            :max="video.state.length"
            type="range"
            step="1"
            v-model="video.state.timeNow"
          />
        </div>
        <div class="progressbar__time end">{{ formatTime(video.state.length).minutes }}:{{ formatTime(video.state.length).seconds }}</div>
      </div>
    </div>
  </div>
</template>

<script>
export default {
  name: "VideoPlayer",
  props: {
    videoSources: {
      type: Array,
      required: true,
      validator(sources) {
        return sources.every(source => source.src && source.type);
      },
    },
    title: {
      type: String,
      default: "Video Title",
    },
    loader: {
      type: String,
      default: "Loading...",
    },
  },
  data() {
    return {
      ready: false,
      loading: true,
      video: {
        state: {
          playing: false,
          timeNow: 0,
          length: 0,
          position: 0,
        },
      },
    };
  },
  methods: {
    setLength(event) {
      this.video.state.length = this.$refs.videoElement.duration;
    },
    timeUpdateFunction(event) {
      this.video.state.timeNow = this.$refs.videoElement.currentTime;
      this.video.state.position = (this.video.state.timeNow / this.video.state.length) * 100;
    },
    timeChangeBack() {
      this.$refs.videoElement.currentTime -= 10; // Перемотка назад на 10 секунд
    },
    timeChangeFw() {
      this.$refs.videoElement.currentTime += 10; // Перемотка вперед на 10 секунд
    },
    formatTime(time) {
      const minutes = Math.floor(time / 60);
      const seconds = Math.floor(time % 60).toString().padStart(2, "0");
      return { minutes, seconds };
    },
  },
};
</script>

<style scoped>
.video-player {
  position: relative;
  max-width: 640px;
  margin: 0 auto;
}

.video-player__video {
  position: relative;
  width: 100%;
}

.video-player__controls {
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 10px;
}

.progressbar {
  width: 100%;
  display: flex;
  align-items: center;
}

.progressbar__progress {
  width: 100%;
  height: 5px;
  background-color: #ddd;
  position: relative;
}

.progressbar__progress .trumb {
  position: absolute;
  top: -5px;
  width: 10px;
  height: 10px;
  background-color: #000;
  border-radius: 50%;
}

input[type='range'] {
  width: 100%;
}
</style>
